<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>Drop Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="228"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Súbor/URL „%1“ momentálne nie je možné vložiť do rýchleho spustenia</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="334"/>
        <source>Drop application
icons here</source>
        <translation>Sem pretiahnite
ikonu aplikácie</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + ťahanie)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Presunúť vľavo</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Presunúť vpravo</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Odstrániť z rýchleho spustenia</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Obnoviť</translation>
    </message>
</context>
</TS>
